@@ -3,6 +3,12 @@
 package Crypt::Random::Source::Base;
 use Squirrel;
 
+sub available { 0 }
+
+sub rank { 0 }
+
+sub seed { }
+
 sub get { die "abstract" }
 
 # cannibalized from IO::Scalar
@@ -58,6 +64,25 @@ work-alike.
 Note that subclasses override this to operate on a real handle directly if
 available.
 
+=item seed @stuff
+
+On supporting sources this method will add C<@stuff>, whatever it may be, to
+the random seed.
+
+Some sources may not support this, so be careful.
+
+=item available
+
+This is a class method, such that when it returns true calling C<new> without
+arguments on the class should provide a working source of random data.
+
+This is use by L<Crypt::Random::Source::Factory>.
+
+=item rank
+
+This is a class method, with some futz value for a ranking, to help known good
+sources be tried before known bad (slower, less available) sources.
+
 =back
 
 =cut
